import{e as l,b as o,y as a,g as r,O as c,t as g,bj as u,h as s,aO as m}from"./jwt-decode.esm-BJTSBhUK.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dbc6a8e3-8055-461b-8ed6-3667676163e9",e._sentryDebugIdIdentifier="sentry-dbid-dbc6a8e3-8055-461b-8ed6-3667676163e9")}catch{}})();const f={class:"logo"},b=["src","alt"],y=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){u(i=>({v4521d904:n.value}));const t=e,n=o(()=>t.size==="small"?"24px":t.size==="large"?"80px":"50px"),d=o(()=>`${t.brandName} Logo`);return(i,p)=>(s(),a("div",f,[e.imageUrl?(s(),a("img",{key:0,class:"logo-img",src:e.imageUrl,alt:d.value},null,8,b)):r("",!0),e.hideText?r("",!0):(s(),a("span",{key:1,class:c(e.size)},g(e.brandName),3))]))}}),_=m(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-3Y-n1Ku6.js.map
