import{e as n,ai as r,N as i,y as s,h as d,m as c,j as p,b8 as f,aO as l}from"./jwt-decode.esm-BJTSBhUK.js";import{u}from"./organizationSwitcher-BA40_kEX.js";import"./router-JNJkT0FW.js";import"./ts.worker-_F6qeu5Y.js";import"./organization-DbQPClux.js";import"./tables-COuMqsTr.js";import"./record-COWr9r4M.js";import"./string-C1f4nly_.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="30217199-d6ab-4d16-abc3-305d03ade60e",o._sentryDebugIdIdentifier="sentry-dbid-30217199-d6ab-4d16-abc3-305d03ade60e")}catch{}})();const m={class:"loading-container"},_=n({__name:"RootRedirector",setup(o){const a=u(),t=r();return i(async()=>{const e=await a.selectDefaultOrganization();e.name==="organization"&&e.params?.organizationId?window.location.href=`/organizations/${e.params.organizationId}`:e.name==="onboarding"?window.location.href="/onboarding":t.replace(e)}),(e,g)=>(d(),s("div",m,[c(p(f),{size:"large"})]))}}),k=l(_,[["__scopeId","data-v-a77ce5c1"]]);export{k as default};
//# sourceMappingURL=RootRedirector-oPqagrXT.js.map
