import{C as p,_ as i}from"./View.vue_vue_type_script_setup_true_lang-D-CYMNjy.js";import{e as n,an as s,f as m,h as a,j as f}from"./jwt-decode.esm-BJTSBhUK.js";import"./router-JNJkT0FW.js";import"./ts.worker-_F6qeu5Y.js";import"./fetch-6ZdEdsKW.js";import"./record-COWr9r4M.js";import"./SaveButton-BKmGZFYz.js";import"./ExclamationCircleOutlined-DzrLiLiH.js";import"./CrudView-xgqfvJMN.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-jdUos6Ps.js";import"./constants-CIm3pvgY.js";import"./url-D-YE6ZXS.js";import"./PhDotsThreeVertical.vue-BrfgJanq.js";import"./index-BM0-PlaO.js";import"./asyncComputed-BvQLJepS.js";import"./omniChatStore-DPEXXLq8.js";import"./contracts.generated-CKbKiv7C.js";import"./runnerData-Baasrs_-.js";import"./colorHelpers-CjEM1kZB.js";import"./uuid-qERZoXwB.js";import"./PhCopySimple.vue-aCVitaf1.js";import"./PhPencil.vue-X590M3TX.js";import"./useCodebaseEvents-D7dqFoV3.js";import"./index-Du2sjeXv.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="5e3c3bbf-93f2-4ecc-9a1b-0fa50b8e4f67",o._sentryDebugIdIdentifier="sentry-dbid-5e3c3bbf-93f2-4ecc-9a1b-0fa50b8e4f67")}catch{}})();const G=n({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,d)=>(a(),m(i,{"env-var-repository":f(t),mode:"console"},null,8,["env-var-repository"]))}});export{G as default};
//# sourceMappingURL=EnvVars-p_zbKkxZ.js.map
