import{e as _,ai as m,an as p,i as n,f,h as c,w as i,y,V as g,a2 as v,m as w,j as r,D as k,t as I}from"./jwt-decode.esm-BJTSBhUK.js";import{A as D,T}from"./index-B-rtXwyD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9e5511e7-a70c-450a-920c-812eed147cde",e._sentryDebugIdIdentifier="sentry-dbid-9e5511e7-a70c-450a-920c-812eed147cde")}catch{}})();const x=_({__name:"TablesTabs",setup(e){const a=m(),t=p(),d=String(t.name),u=t.params.projectId,l=[{label:n.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:n.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:n.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:u}})};return(o,h)=>(c(),f(r(T),{"active-key":r(d),options:l,"onUpdate:activeKey":b},{default:i(()=>[(c(),y(g,null,v(l,s=>w(r(D),{key:s.value,name:s.value},{tab:i(()=>[k("span",null,I(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{x as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-CPegJjgD.js.map
