import{aO as l,y as c,h as n,D as a,A as s,g as d,e as u,R as f,f as p,j as r}from"./jwt-decode.esm-BJTSBhUK.js";import{O as _}from"./OmniChat-Bb5lE1Cf.js";import{u as h}from"./omniChatStore-DPEXXLq8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1efce85e-eb4c-427c-9ac2-95ecf72d426b",e._sentryDebugIdIdentifier="sentry-dbid-1efce85e-eb4c-427c-9ac2-95ecf72d426b")}catch{}})();const m={},y={class:"project-layout"},b={class:"project-navbar"},j={class:"project-body"},g={key:0,class:"project-sidebar"},I={class:"project-content"},k={key:1,class:"project-chat"};function v(e,o){return n(),c("div",y,[a("header",b,[s(e.$slots,"navbar",{},void 0,!0)]),a("section",j,[e.$slots.sidebar?(n(),c("aside",g,[s(e.$slots,"sidebar",{},void 0,!0)])):d("",!0),a("main",I,[s(e.$slots,"content",{},void 0,!0)]),e.$slots.chat?(n(),c("aside",k,[s(e.$slots,"chat",{},void 0,!0)])):d("",!0)])])}const O=l(m,[["render",v],["__scopeId","data-v-2a4d09fc"]]),B=u({__name:"ConsoleOmniChat",props:{projectId:{}},setup(e){const o=e,t=h();return f(()=>o.projectId,i=>t.init("console",i),{immediate:!0}),(i,w)=>r(t).controller&&r(t).repository?(n(),p(_,{key:0,"ai-chat-repository":r(t).repository,controller:r(t).controller,environment:{origin:"console",projectId:o.projectId},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):d("",!0)}});export{O as P,B as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang-qimus8ge.js.map
