import{i as h}from"./metadata-BrjsRBTu.js";import{W as w}from"./Watermark-B7avhfAc.js";import{F as v}from"./PhArrowSquareOut.vue-BrNrSMwb.js";import{e as b,b as x,r as C,y as f,g as D,j as e,m as p,w as s,J as u,f as r,k as y,t as _,i as I,b3 as g,V as z,a2 as F,ai as V,h as a,O as B,a0 as L,aO as N}from"./jwt-decode.esm-BJTSBhUK.js";import{u as O}from"./workspaceStore-B-8M4YJE.js";import{C as S}from"./index-B-rtXwyD.js";import{L as T}from"./LoadingOutlined-CQHvvC_w.js";import"./PhHouse.vue-KJ0DGcmx.js";import"./PhMagnifyingGlass.vue-B789v7Yz.js";import"./PhRobot.vue-CwNUFQ6j.js";import"./PhWebhooksLogo.vue-Dj5dUur5.js";import"./constants-CIm3pvgY.js";import"./userStore-2QX-Aqji.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="8dee490d-55c0-4207-9848-3676e84f0ec1",o._sentryDebugIdIdentifier="sentry-dbid-8dee490d-55c0-4207-9848-3676e84f0ec1")}catch{}})();const W={key:0,class:"home-container"},j=b({__name:"Home",setup(o){const n=V(),i=O(),d=x(()=>i.state.workspace?.sidebar.filter(c=>c.id!=="home")||[]),l=C(null),k=async(c,m)=>{l.value=m,await n.push({path:`/${c}`}),l.value=null};return(c,m)=>e(i).state.workspace?(a(),f("div",W,[p(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[d.value.length===0?(a(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),f(z,{key:1},F(d.value,t=>(a(),r(e(S),{key:t.id,class:B(["form-card",{loading:l.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>k(t.path,t.id)},{default:s(()=>[p(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(a(),r(L(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(_(t.name),1)]),_:2},1024),l.value!==t.id?(a(),r(e(v),{key:0,size:"20"})):(a(),r(e(T),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(w,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):D("",!0)}}),te=N(j,[["__scopeId","data-v-132e66ff"]]);export{te as default};
//# sourceMappingURL=Home-DzVe_zW1.js.map
