import{N as l}from"./Navbar-B6Tru7cU.js";import{B as f}from"./BaseLayout-Dyp0CrSy.js";import{C as b}from"./ContentLayout-D-7K87cX.js";import{e as g,an as _,b as r,ab as v,f as e,h as i,w as n,m as c,g as y}from"./jwt-decode.esm-BJTSBhUK.js";import{_ as w}from"./BillingAlert.vue_vue_type_script_setup_true_lang-Ut0zr340.js";import{u as z}from"./projectsStore-CPWh8BWW.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-CmsDa9wk.js";import"./constants-CIm3pvgY.js";import"./keyboard-fj_TXqaH.js";import"./os-DmKaYsNa.js";import"./router-JNJkT0FW.js";import"./ts.worker-_F6qeu5Y.js";import"./organization-DbQPClux.js";import"./project-CNNVe7L3.js";import"./record-COWr9r4M.js";import"./tables-COuMqsTr.js";import"./string-C1f4nly_.js";import"./organizationSwitcher-BA40_kEX.js";import"./folder-BMJ9syX0.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-BY1bFd78.js";import"./member-CiZB7vof.js";import"./index-7CEdotyr.js";import"./index-B-rtXwyD.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang--tY3s0v4.js";import"./PhNotePencil.vue-B4GMdW6u.js";import"./PhSignOut.vue-C8c-1xgx.js";import"./index-BM0-PlaO.js";import"./index--5jTk1Oz.js";import"./PhPlus.vue-CJ6dnZOm.js";import"./omniChatStore-DPEXXLq8.js";import"./contracts.generated-CKbKiv7C.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";import"./uuid-qERZoXwB.js";import"./PhCopySimple.vue-aCVitaf1.js";import"./index-CXnCZjBw.js";import"./index-Du2sjeXv.js";import"./ant-design-BuzQ_h-F.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="f6c162c8-c3b6-4842-ab67-56fcd4798562",t._sentryDebugIdIdentifier="sentry-dbid-f6c162c8-c3b6-4842-ab67-56fcd4798562")}catch{}})();const ct=g({__name:"Organization",setup(t){const o=_(),m=z(),p=r(()=>o.params.organizationId),a=r(()=>m.fetchedState?.organization),d=r(()=>a.value?{organizationId:a.value.id}:void 0),s=r(()=>a.value?.billingMetadata);return(I,C)=>{const u=v("RouterView");return i(),e(f,null,{navbar:n(()=>[c(l,{"use-cascader":!0,"cascader-props":d.value},null,8,["cascader-props"])]),content:n(()=>[c(b,null,{default:n(()=>[s.value?(i(),e(w,{key:0,"billing-metadata":s.value,"organization-id":p.value},null,8,["billing-metadata","organization-id"])):y("",!0),(i(),e(u,{key:p.value}))]),_:1})]),_:1})}}});export{ct as default};
//# sourceMappingURL=Organization-Bl2ly5Oc.js.map
