import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-ikKVV7cX.js";import{B as y}from"./BaseLayout-Dyp0CrSy.js";import{e as l,Z as _,a8 as b,aO as u,aK as v,aL as g,h as f,y as h,D as o,U as s,N as w,ai as S,f as k,w as n,an as B,m as i,j as I}from"./jwt-decode.esm-BJTSBhUK.js";import{u as L}from"./editor-r0htiUGw.js";import{A as $}from"./index-CXnCZjBw.js";import"./logo-BiWG9_W5.js";import"./Logo-3Y-n1Ku6.js";import"./workspaceStore-B-8M4YJE.js";import"./userStore-2QX-Aqji.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";import"./useCodebaseEvents-D7dqFoV3.js";import"./contracts.generated-CKbKiv7C.js";import"./ts.worker-_F6qeu5Y.js";import"./router-B0piOgcW.js";import"./constants-CIm3pvgY.js";import"./linters-C-9YxxUw.js";import"./asyncComputed-BvQLJepS.js";import"./index-BM0-PlaO.js";import"./index--5jTk1Oz.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="fa5beb79-fd62-400d-b6f0-2a7f897462c3",e._sentryDebugIdIdentifier="sentry-dbid-fa5beb79-fd62-400d-b6f0-2a7f897462c3")}catch{}})();const D=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),x={class:"v-spinner"};function K(e,r,a,d,c,p){return v((f(),h("div",x,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(D,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),d=L();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:n(()=>[i(I($),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[o("div",R,[i(P)])]),_:1}))}}),re=u(j,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-CrmJXICY.js.map
