import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-SlWhAgyY.js";import{e as i,y as d,m as u,j as n,ai as m,an as l,h as _,aO as f}from"./jwt-decode.esm-BJTSBhUK.js";import{u as b}from"./workspaceStore-B-8M4YJE.js";import"./OTPInput-C0tjwO--.js";import"./Logo-3Y-n1Ku6.js";import"./string-C1f4nly_.js";import"./CircularLoading-BSvgsM2c.js";import"./index-Du2sjeXv.js";import"./userStore-2QX-Aqji.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9bc1ceb0-5684-49eb-87e3-082e6c1db7ad",e._sentryDebugIdIdentifier="sentry-dbid-9bc1ceb0-5684-49eb-87e3-082e6c1db7ad")}catch{}})();const y={class:"runner"},g=i({__name:"Login",setup(e){const o=m(),r=l(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(_(),d("div",y,[u(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=f(g,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-CKPlO88C.js.map
