import{A as n}from"./index-C7dxzsX-.js";import{e as a,b as o,y as r,g as c,O as d,m as l,j as f,h as p,aO as i}from"./jwt-decode.esm-BJTSBhUK.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="4dbdc952-0554-4aa6-a689-c35c09c2ee18",e._sentryDebugIdIdentifier="sentry-dbid-4dbdc952-0554-4aa6-a689-c35c09c2ee18")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(p(),r("nav",{key:0,class:d(["p-steps",{"full-screen":!e.isPreview}])},[l(f(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-C0OQzrYd.js.map
