import{P as g}from"./PlayerNavbar-BlyxeU2i.js";import{e as _,an as i,r as h,b as y,y as b,f as k,g as v,D as w,j as n,m as L,ab as C,ai as I,h as c,aO as N}from"./jwt-decode.esm-BJTSBhUK.js";import{u as D}from"./workspaceStore-B-8M4YJE.js";import"./userStore-2QX-Aqji.js";import"./metadata-BrjsRBTu.js";import"./PhHouse.vue-KJ0DGcmx.js";import"./PhMagnifyingGlass.vue-B789v7Yz.js";import"./PhRobot.vue-CwNUFQ6j.js";import"./PhWebhooksLogo.vue-Dj5dUur5.js";import"./LoadingOutlined-CQHvvC_w.js";import"./PhSignOut.vue-C8c-1xgx.js";import"./index--5jTk1Oz.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="3908f9f3-e19e-47b8-9faa-fe54e57dcffc",o._sentryDebugIdIdentifier="sentry-dbid-3908f9f3-e19e-47b8-9faa-fe54e57dcffc")}catch{}})();const V={class:"main-container"},B={class:"content"},R=_({__name:"Main",setup(o){const e=I(),t=D(),p=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},f=y(()=>!!i().meta.hideLogin);return(r,s)=>{const m=C("RouterView");return c(),b("div",V,[n(t).state.workspace?(c(),k(g,{key:0,"current-path":n(p),"hide-login":f.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",B,[L(m)])])}}}),J=N(R,[["__scopeId","data-v-f095bece"]]);export{J as default};
//# sourceMappingURL=Main-DS2FAIes.js.map
