import{p as s,q as i,v as f}from"./jwt-decode.esm-BJTSBhUK.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a1e84f96-08b8-4005-b2dc-fc690e8cffe6",e._sentryDebugIdIdentifier="sentry-dbid-a1e84f96-08b8-4005-b2dc-fc690e8cffe6")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:d,TimePicker:m,QuarterPicker:c,RangePicker:o}=s(i),g=f(n,{WeekPicker:t,MonthPicker:r,YearPicker:d,RangePicker:o,TimePicker:m,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(c.name,c),e)});export{g as D,r as M,c as Q,o as R,t as W};
//# sourceMappingURL=dayjs-B4FQdh-n.js.map
