import{O as l}from"./workspaceStore-B-8M4YJE.js";import{e as c,N as f,y as u,m as n,w as o,j as a,ao as _,T as b,k as r,t as i,i as s,h as p}from"./jwt-decode.esm-BJTSBhUK.js";import"./userStore-2QX-Aqji.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4040d8a2-cb44-4719-93bd-ebffe1837819",e._sentryDebugIdIdentifier="sentry-dbid-4040d8a2-cb44-4719-93bd-ebffe1837819")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,d)=>(p(),u("div",null,[n(a(_),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(b),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-CoyhmnSJ.js.map
