import{aO as c,y as o,A as s,D as n,g as d,h as a}from"./jwt-decode.esm-BJTSBhUK.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6a01389e-7c81-41ca-8119-aa7075cc23b6",e._sentryDebugIdIdentifier="sentry-dbid-6a01389e-7c81-41ca-8119-aa7075cc23b6")}catch{}})();const r={},i={class:"base-layout"},l={class:"base-middle"},f={class:"content"},u={class:"left"},_={key:0,class:"base-footer"},b={key:0};function y(e,t){return a(),o("div",i,[s(e.$slots,"sidebar",{},void 0,!0),n("section",l,[s(e.$slots,"navbar",{},void 0,!0),n("section",f,[n("section",u,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(a(),o("section",_,[s(e.$slots,"footer",{},void 0,!0)])):d("",!0)]),e.$slots.chat?(a(),o("section",b,[s(e.$slots,"chat",{},void 0,!0)])):d("",!0)])])])}const g=c(r,[["render",y],["__scopeId","data-v-da85ecdc"]]);export{g as B};
//# sourceMappingURL=BaseLayout-Dyp0CrSy.js.map
