import{aT as r,aU as n,ac as o,aV as p,aW as d,aX as c,aY as m,aZ as f,a_ as u,a$ as s,b0 as b,b1 as g,b2 as l}from"./jwt-decode.esm-BJTSBhUK.js";import{b as y,s as w,g as _}from"./workspaceStore-B-8M4YJE.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-ClLgEd-A.js";import{r as i}from"./router-B0piOgcW.js";import"./userStore-2QX-Aqji.js";import"./runnerData-Baasrs_-.js";import"./url-D-YE6ZXS.js";import"./colorHelpers-CjEM1kZB.js";import"./PlayerConfigProvider-CUyQXD4o.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="e14dbae3-4399-4f57-879c-106a72db8184",t._sentryDebugIdIdentifier="sentry-dbid-e14dbae3-4399-4f57-879c-106a72db8184")}catch{}})();class I{static init(){setInterval(()=>{y("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await _(),a=r(),e=n({render:()=>o(h)});p.init(),d(e,i,t),I.init(),e.use(i),e.use(a),e.use(c),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",f),e.component("Message",u),s(e,b),s(e,g),s(e,l)})();
//# sourceMappingURL=player-B5udKuZh.js.map
